@@ -12,6 +12,7 @@
 #' @param pow Power to which the average of correlations is to be raised.  Only 
 #' applies to the "gaussian" model.  Default is 2 to yield R-square but can be on to 
 #' show correlations.  Pow is ignored for the family of "cox" and "binomial".
+#' @param bootstrap 1 if a bootstrap fit was done as opposed to a (neted) CV. 
 #' 
 #' @return An estimate, 95% CI and p for agreement comparison 
 #' 
@@ -19,7 +20,7 @@
 #'
 #' @noRd
 #' 
-nested.compare0_0_5_3 = function( a, b, pow=1, bootstrap=0, digits=4, txt=0 ) { 
+nested.compare0_0_6_1 = function( a, b, pow=1, bootstrap=0, digits=4, txt=0 ) { 
   if ( pow != 2) { pow = 1 } 
   if (pow == 1) {
     dff = (a-b)[!is.na(a-b)]
@@ -89,7 +90,7 @@ nested.compare0_0_5_3 = function( a, b, pow=1, bootstrap=0, digits=4, txt=0 ) {
 #' 
 #' @noRd
 #' 
-nested.compare_0_5_3 = function( object, type="devrat", digits=4, pow=1 ) {
+nested.compare_0_6_1 = function( object, type="devrat", digits=4, pow=1 ) {
   family =  object$sample[1]
   tuning  = object$tuning
   bootstrap = tuning[8] 
@@ -102,7 +103,8 @@ nested.compare_0_5_3 = function( object, type="devrat", digits=4, pow=1 ) {
   dostep  = fits[6]
   doaic   = fits[7]
   doorf   = fits[8]
-  if (is.na(doorf)) { doorf = 0 }
+  dofull  = fits[9]
+#  if (is.na(doorf)) { doorf = 0 }
   
   ensemble  = object$ensemble 
   
@@ -202,7 +204,7 @@ nested.compare_0_5_3 = function( object, type="devrat", digits=4, pow=1 ) {
     } else if (type == "intcal") { rpart.perf.rep  = object$rpart.intcal.rep }
   }
   
-  if (dostep == 1) {
+  if ((dostep == 1) | (dofull == 1))  {
     if (type == "agree") {
       step.perf.rep  = object$step.agree.rep
     } else if (type == "devrat") {
@@ -216,7 +218,7 @@ nested.compare_0_5_3 = function( object, type="devrat", digits=4, pow=1 ) {
     } else if (type == "lincal") { step.perf.rep  = object$step.lincal.rep
     } else if (type == "intcal") { step.perf.rep  = object$step.intcal.rep }
   }   
-  
+
   #  pow = 1 
   
   if (type == "agree") {
@@ -253,28 +255,32 @@ nested.compare_0_5_3 = function( object, type="devrat", digits=4, pow=1 ) {
   
   if ( ensemble[c(1)] == 0 ) {
     cat ("\n Simple models with information from losso not run.  Output is abbreviated. \n\n" ) 
-    doxgb = 0 ; dorf = 0 ; doorf = 0 ; doann = 0 ; dorpart = 0 ; dostep = 0 ; doaic = 0 ; 
+    doxgb = 0 ; dorf = 0 ; doorf = 0 ; doann = 0 ; dorpart = 0 ; dostep = 0 ; doaic = 0 ; dofull = 0 ; 
   }
   
   cat ("  Model performance comparison in terms of", pm, "\n\n" )   
   cat ("  Comparison                                estimate   (95% CI)         p\n") 
   
   if (dolasso == 1) {
-    cat ("\n lasso.minR  - lasso.min                     ") ;  nested.compare0_0_5_3(lasso.perf.rep[,4] , lasso.perf.rep[,2], pow, bootstrap, digits) 
-    cat ("\n lasso.minR  - lasso.minR0                   ") ;  nested.compare0_0_5_3(lasso.perf.rep[,4] , lasso.perf.rep[,6], pow, bootstrap, digits)   
-    cat ("\n lasso.min   - lasso.minR0                   ") ;  nested.compare0_0_5_3(lasso.perf.rep[,2] , lasso.perf.rep[,6], pow, bootstrap, digits)   
+    cat ("\n lasso.minR  - lasso.min                     ") ;  nested.compare0_0_6_1(lasso.perf.rep[,2] , lasso.perf.rep[,1], pow, bootstrap, digits) 
+    cat ("\n lasso.minR  - lasso.minR0                   ") ;  nested.compare0_0_6_1(lasso.perf.rep[,2] , lasso.perf.rep[,3], pow, bootstrap, digits)   
+    if (!is.null(object$cv_elastic_fit)) {
+      cat ("\n lasso.minR  - elastic net                   ") ;  nested.compare0_0_6_1(lasso.perf.rep[,2] , lasso.perf.rep[,4], pow, bootstrap, digits)   
+    }
+    cat ("\n lasso.minR  - ridge                         ") ;  nested.compare0_0_6_1(lasso.perf.rep[,2] , lasso.perf.rep[,5], pow, bootstrap, digits)   
+    cat ("\n lasso.min   - lasso.minR0                   ") ;  nested.compare0_0_6_1(lasso.perf.rep[,1] , lasso.perf.rep[,3], pow, bootstrap, digits)   
     cat("\n")
   }
   
   #  print(xgb.perf.rep)
   
   if (doxgb == 1) {
-    cat ("\n XGBoost (tuned) - XGBoost (simple)          ") ;  nested.compare0_0_5_3(xgb.perf.rep[,4] , xgb.perf.rep[,1], pow, bootstrap, digits)  
+    cat ("\n XGBoost (tuned) - XGBoost (simple)          ") ;  nested.compare0_0_6_1(xgb.perf.rep[,4] , xgb.perf.rep[,1], pow, bootstrap, digits)  
     if (sum(ensemble[c(2,6)])> 0) {
-      cat ("\n XGBoost (tuned) lasso feature - no feature  ") ;  nested.compare0_0_5_3(xgb.perf.rep[,5] , xgb.perf.rep[,4], pow, bootstrap, digits)   
+      cat ("\n XGBoost (tuned) lasso feature - no feature  ") ;  nested.compare0_0_6_1(xgb.perf.rep[,5] , xgb.perf.rep[,4], pow, bootstrap, digits)   
     }
     if (sum(ensemble[c(3,4,7,8)])> 0) {
-      cat ("\n XGBoost (tuned) lasso offset - no offset    ") ;  nested.compare0_0_5_3(xgb.perf.rep[,6] , xgb.perf.rep[,4], pow, bootstrap, digits)   
+      cat ("\n XGBoost (tuned) lasso offset - no offset    ") ;  nested.compare0_0_6_1(xgb.perf.rep[,6] , xgb.perf.rep[,4], pow, bootstrap, digits)   
     }
     cat("\n")
   }
@@ -282,11 +288,11 @@ nested.compare_0_5_3 = function( object, type="devrat", digits=4, pow=1 ) {
   if (dorf == 1) {
     lr = 0 
     if (sum(ensemble[c(2,6)])> 0) {
-      cat ("\n RF with lasso feature - no feature          ") ;  nested.compare0_0_5_3(rf.perf.rep[,2] , rf.perf.rep[,1], pow, bootstrap, digits)   
+      cat ("\n RF with lasso feature - no feature          ") ;  nested.compare0_0_6_1(rf.perf.rep[,2] , rf.perf.rep[,1], pow, bootstrap, digits)   
       lr = 1 
     }
     if ((sum(ensemble[c(3,4,7,8)])> 0) & (family == "gaussian")) {
-      cat ("\n RF with lasso offset - no offset            ") ;  nested.compare0_0_5_3(rf.perf.rep[,3] , rf.perf.rep[,1], pow, bootstrap, digits)   
+      cat ("\n RF with lasso offset - no offset            ") ;  nested.compare0_0_6_1(rf.perf.rep[,3] , rf.perf.rep[,1], pow, bootstrap, digits)   
       lr = 1 
     }
     if (lr == 1) { cat("\n") } 
@@ -295,11 +301,11 @@ nested.compare_0_5_3 = function( object, type="devrat", digits=4, pow=1 ) {
   if (doorf == 1) {
     lr = 0 
     if (sum(ensemble[c(2,6)])> 0) {
-      cat ("\n ORF with lasso feature - no feature          ") ;  nested.compare0_0_5_3(orf.perf.rep[,2] , orf.perf.rep[,1], pow, bootstrap, digits)   
+      cat ("\n ORF with lasso feature - no feature          ") ;  nested.compare0_0_6_1(orf.perf.rep[,2] , orf.perf.rep[,1], pow, bootstrap, digits)   
       lr = 1 
     }
     if ((sum(ensemble[c(3,4,7,8)])> 0) & (family == "gaussian")) {
-      cat ("\n ORF with lasso offset - no offset            ") ;  nested.compare0_0_5_3(orf.perf.rep[,3] , orf.perf.rep[,1], pow, bootstrap, digits)   
+      cat ("\n ORF with lasso offset - no offset            ") ;  nested.compare0_0_6_1(orf.perf.rep[,3] , orf.perf.rep[,1], pow, bootstrap, digits)   
       lr = 1 
     }
     if (lr == 1) { cat("\n") } 
@@ -308,118 +314,128 @@ nested.compare_0_5_3 = function( object, type="devrat", digits=4, pow=1 ) {
   if (doann == 1) {
     lr = 0 
     if (sum(ensemble[6])> 0) {
-      cat ("\n ANN with with lasso feature - no feature    ") ;  nested.compare0_0_5_3(ann.perf.rep[,6] , ann.perf.rep[,1], pow, bootstrap, digits) ; lr = 1 ;
+      cat ("\n ANN with with lasso feature - no feature    ") ;  nested.compare0_0_6_1(ann.perf.rep[,6] , ann.perf.rep[,1], pow, bootstrap, digits) ; lr = 1 ;
     } else if (sum(ensemble[2])> 0) {
-      cat ("\n ANN with with lasso feature - no feature    ") ;  nested.compare0_0_5_3(ann.perf.rep[,2] , ann.perf.rep[,1], pow, bootstrap, digits) ; lr = 1 ;
+      cat ("\n ANN with with lasso feature - no feature    ") ;  nested.compare0_0_6_1(ann.perf.rep[,2] , ann.perf.rep[,1], pow, bootstrap, digits) ; lr = 1 ;
       
     } 
     if (sum(ensemble[8])> 0) { 
-      cat ("\n ANN with with lasso offset - no offset      ") ;  nested.compare0_0_5_3(ann.perf.rep[,8] , ann.perf.rep[,1], pow, bootstrap, digits) ; lr = 1 ;
+      cat ("\n ANN with with lasso offset - no offset      ") ;  nested.compare0_0_6_1(ann.perf.rep[,8] , ann.perf.rep[,1], pow, bootstrap, digits) ; lr = 1 ;
     } else if (sum(ensemble[7])> 0) { 
-      cat ("\n ANN with with lasso offset - no offset      ") ;  nested.compare0_0_5_3(ann.perf.rep[,7] , ann.perf.rep[,1], pow, bootstrap, digits) ; lr = 1 ;
+      cat ("\n ANN with with lasso offset - no offset      ") ;  nested.compare0_0_6_1(ann.perf.rep[,7] , ann.perf.rep[,1], pow, bootstrap, digits) ; lr = 1 ;
     } else     if (sum(ensemble[4])> 0) { 
-      cat ("\n ANN with with lasso offset - no offset      ") ;  nested.compare0_0_5_3(ann.perf.rep[,4] , ann.perf.rep[,1], pow, bootstrap, digits) ; lr = 1 ;
+      cat ("\n ANN with with lasso offset - no offset      ") ;  nested.compare0_0_6_1(ann.perf.rep[,4] , ann.perf.rep[,1], pow, bootstrap, digits) ; lr = 1 ;
     } else     if (sum(ensemble[3])> 0) { 
-      cat ("\n ANN with with lasso offset - no offset      ") ;  nested.compare0_0_5_3(ann.perf.rep[,3] , ann.perf.rep[,1], pow, bootstrap, digits) ; lr = 1 ;
+      cat ("\n ANN with with lasso offset - no offset      ") ;  nested.compare0_0_6_1(ann.perf.rep[,3] , ann.perf.rep[,1], pow, bootstrap, digits) ; lr = 1 ;
     } 
     if (lr == 1) { cat("\n") } 
   }
   
   if (dostep == 1) {
-    cat ("\n step (df) - step (p)                        ") ;  nested.compare0_0_5_3(step.perf.rep[,1]      , step.perf.rep[,2], pow, bootstrap, digits) ;  cat("\n")
+    cat ("\n step (df) - step (p)                        ") ;  nested.compare0_0_6_1(step.perf.rep[,1]      , step.perf.rep[,2], pow, bootstrap, digits) ;  cat("\n")
   }
   
   #  cat("\n")
   
+  if ((dolasso == 1) & (dostep == 1)) {
+    cat ("\n lasso.minR0 - step (p)          ") ;  nested.compare0_0_6_1(lasso.perf.rep[,3] , step.perf.rep[,2], pow, bootstrap, digits)   
+  }
+
+  if ((dolasso == 1) & (dofull == 1)) {
+    cat ("\n lasso.minR - full model                     ") ;  nested.compare0_0_6_1(lasso.perf.rep[,2] , step.perf.rep[,4], pow, bootstrap, digits) 
+    cat("\n")
+  }
+  
+    
   if ((dolasso == 1) & (doxgb == 1)) {
-    cat ("\n lasso.minR - XGB (tuned)                    ") ;  nested.compare0_0_5_3(lasso.perf.rep[,4] , xgb.perf.rep[,4], pow, bootstrap, digits) 
+    cat ("\n lasso.minR - XGB (tuned)                    ") ;  nested.compare0_0_6_1(lasso.perf.rep[,2] , xgb.perf.rep[,4], pow, bootstrap, digits) 
     
     if (sum(ensemble[c(2,6)])> 0) {
-      cat ("\n lasso.minR - XGB with lasso feature         ") ;  nested.compare0_0_5_3(lasso.perf.rep[,4] , xgb.perf.rep[,5], pow, bootstrap, digits) 
+      cat ("\n lasso.minR - XGB with lasso feature         ") ;  nested.compare0_0_6_1(lasso.perf.rep[,2] , xgb.perf.rep[,5], pow, bootstrap, digits) 
     }
     if (sum(ensemble[c(3,4,7,8)])> 0) {
-      cat ("\n lasso.minR - XGB with lasso offset          ") ;  nested.compare0_0_5_3(lasso.perf.rep[,4] , xgb.perf.rep[,6], pow, bootstrap, digits)   
+      cat ("\n lasso.minR - XGB with lasso offset          ") ;  nested.compare0_0_6_1(lasso.perf.rep[,2] , xgb.perf.rep[,6], pow, bootstrap, digits)   
     }
   }
   
   if ((dolasso == 1) & (dorf == 1)) {
-    cat ("\n lasso.minR - Random Forest                  ") ;  nested.compare0_0_5_3(lasso.perf.rep[,4] , rf.perf.rep[,1], pow, bootstrap, digits) 
+    cat ("\n lasso.minR - Random Forest                  ") ;  nested.compare0_0_6_1(lasso.perf.rep[,2] , rf.perf.rep[,1], pow, bootstrap, digits) 
     
     if (sum(ensemble[c(2,6)])> 0) {
-      cat ("\n lasso.minR - RF with lasso feature          ") ;  nested.compare0_0_5_3(lasso.perf.rep[,4] , rf.perf.rep[,2], pow, bootstrap, digits) 
+      cat ("\n lasso.minR - RF with lasso feature          ") ;  nested.compare0_0_6_1(lasso.perf.rep[,2] , rf.perf.rep[,2], pow, bootstrap, digits) 
     }
     if ( (sum(ensemble[c(3,4,7,8)])> 0) & (family == "gaussian") ) {
-      cat ("\n lasso.minR - RF with lasso offset           ") ;  nested.compare0_0_5_3(lasso.perf.rep[,4] , rf.perf.rep[,3], pow, bootstrap, digits)   
+      cat ("\n lasso.minR - RF with lasso offset           ") ;  nested.compare0_0_6_1(lasso.perf.rep[,2] , rf.perf.rep[,3], pow, bootstrap, digits)   
     }
   }
   
   if ((dolasso == 1) & (doorf == 1)) {
-    cat ("\n lasso.minR - Oblique Random Forest          ") ;  nested.compare0_0_5_3(lasso.perf.rep[,4] , orf.perf.rep[,1], pow, bootstrap, digits) 
+    cat ("\n lasso.minR - Oblique Random Forest          ") ;  nested.compare0_0_6_1(lasso.perf.rep[,2] , orf.perf.rep[,1], pow, bootstrap, digits) 
     
     if (sum(ensemble[c(2,6)])> 0) {
-      cat ("\n lasso.minR - ORF with lasso feature         ") ;  nested.compare0_0_5_3(lasso.perf.rep[,4] , orf.perf.rep[,2], pow, bootstrap, digits) 
+      cat ("\n lasso.minR - ORF with lasso feature         ") ;  nested.compare0_0_6_1(lasso.perf.rep[,2] , orf.perf.rep[,2], pow, bootstrap, digits) 
     }
     if ( (sum(ensemble[c(3,4,7,8)])> 0) & (family == "gaussian") ) {
-      cat ("\n lasso.minR - ORF with lasso offset          ") ;  nested.compare0_0_5_3(lasso.perf.rep[,4] , orf.perf.rep[,3], pow, bootstrap, digits)   
+      cat ("\n lasso.minR - ORF with lasso offset          ") ;  nested.compare0_0_6_1(lasso.perf.rep[,2] , orf.perf.rep[,3], pow, bootstrap, digits)   
     }
   }
   
   if ((dolasso == 1) & (doann == 1)) {
-    cat ("\n lasso.minR - ANN                            ") ;  nested.compare0_0_5_3(lasso.perf.rep[,4] , ann.perf.rep[,1], pow, bootstrap, digits) 
+    cat ("\n lasso.minR - ANN                            ") ;  nested.compare0_0_6_1(lasso.perf.rep[,2] , ann.perf.rep[,1], pow, bootstrap, digits) 
     if (ensemble[6]) { 
-      cat ("\n lasso.minR - ANN l lasso feature            ") ;  nested.compare0_0_5_3(lasso.perf.rep[,4] , ann.perf.rep[,6], pow, bootstrap, digits)   
+      cat ("\n lasso.minR - ANN l lasso feature            ") ;  nested.compare0_0_6_1(lasso.perf.rep[,2] , ann.perf.rep[,6], pow, bootstrap, digits)   
     } else if (ensemble[2]) { 
-      cat ("\n lasso.minR - ANN lasso feature              ") ;  nested.compare0_0_5_3(lasso.perf.rep[,4] ,  ann.perf.rep[,2], pow, bootstrap, digits)   
+      cat ("\n lasso.minR - ANN lasso feature              ") ;  nested.compare0_0_6_1(lasso.perf.rep[,2] ,  ann.perf.rep[,2], pow, bootstrap, digits)   
     }  
     if (ensemble[8]) { 
-      cat ("\n lasso.minR - ANN l lasso offset (upated)    ") ;  nested.compare0_0_5_3(lasso.perf.rep[,4] , ann.perf.rep[,8], pow, bootstrap, digits)   
+      cat ("\n lasso.minR - ANN l lasso offset (upated)    ") ;  nested.compare0_0_6_1(lasso.perf.rep[,2] , ann.perf.rep[,8], pow, bootstrap, digits)   
     } else if (ensemble[4]) { 
-      cat ("\n lasso.minR - ANN lasso offset               ") ;  nested.compare0_0_5_3(lasso.perf.rep[,4] , ann.perf.rep[,4], pow, bootstrap, digits)  
+      cat ("\n lasso.minR - ANN lasso offset               ") ;  nested.compare0_0_6_1(lasso.perf.rep[,2] , ann.perf.rep[,4], pow, bootstrap, digits)  
     } else if (ensemble[7]) { 
-      cat ("\n lasso.minR - ANN l lasso offset (upated)    ") ;  nested.compare0_0_5_3(lasso.perf.rep[,4] , ann.perf.rep[,7], pow, bootstrap, digits)   
+      cat ("\n lasso.minR - ANN l lasso offset (upated)    ") ;  nested.compare0_0_6_1(lasso.perf.rep[,2] , ann.perf.rep[,7], pow, bootstrap, digits)   
     }  else if (ensemble[3]) { 
-      cat ("\n lasso.minR - ANN lasso offset               ") ;  nested.compare0_0_5_3(lasso.perf.rep[,4] , ann.perf.rep[,3], pow, bootstrap, digits)   
+      cat ("\n lasso.minR - ANN lasso offset               ") ;  nested.compare0_0_6_1(lasso.perf.rep[,2] , ann.perf.rep[,3], pow, bootstrap, digits)   
     }
   }
   
   if (dolasso) { cat("\n") } 
   
   if ((doxgb == 1) & (dorf == 1)) {
-    cat ("\n XGBoost (tuned) - RF                        ") ;  nested.compare0_0_5_3(xgb.perf.rep[,4] ,  rf.perf.rep[,1], pow, bootstrap, digits)   
+    cat ("\n XGBoost (tuned) - RF                        ") ;  nested.compare0_0_6_1(xgb.perf.rep[,4] ,  rf.perf.rep[,1], pow, bootstrap, digits)   
     if (sum(ensemble[c(2,6)]) > 0) {
-      cat ("\n XGBoost lasso feature-RF with lasso feature ") ;  nested.compare0_0_5_3(xgb.perf.rep[,5] ,  rf.perf.rep[,2], pow, bootstrap, digits)   
+      cat ("\n XGBoost lasso feature-RF with lasso feature ") ;  nested.compare0_0_6_1(xgb.perf.rep[,5] ,  rf.perf.rep[,2], pow, bootstrap, digits)   
     } 
     if ( (sum(ensemble[c(3,4,7,8)]) > 0)  & (family == "gaussian") ) {
-      cat ("\n XGBoost lasso offset-  RF with lasso offset ") ;  nested.compare0_0_5_3(xgb.perf.rep[,6] ,  rf.perf.rep[,3], pow, bootstrap, digits)   
+      cat ("\n XGBoost lasso offset-  RF with lasso offset ") ;  nested.compare0_0_6_1(xgb.perf.rep[,6] ,  rf.perf.rep[,3], pow, bootstrap, digits)   
     }
   }
   
   if ((doxgb == 1) & (doorf == 1)) {
-    cat ("\n XGBoost (tuned) - ORF                       ") ;  nested.compare0_0_5_3(xgb.perf.rep[,4] ,  orf.perf.rep[,1], pow, bootstrap, digits)   
+    cat ("\n XGBoost (tuned) - ORF                       ") ;  nested.compare0_0_6_1(xgb.perf.rep[,4] ,  orf.perf.rep[,1], pow, bootstrap, digits)   
     if (sum(ensemble[c(2,6)]) > 0) {
-      cat ("\n XGBoost lasso feature-ORF with lasso feature") ;  nested.compare0_0_5_3(xgb.perf.rep[,5] ,  orf.perf.rep[,2], pow, bootstrap, digits)   
+      cat ("\n XGBoost lasso feature-ORF with lasso feature") ;  nested.compare0_0_6_1(xgb.perf.rep[,5] ,  orf.perf.rep[,2], pow, bootstrap, digits)   
     } 
     if ( (sum(ensemble[c(3,4,7,8)]) > 0)  & (family == "gaussian") ) {
-      cat ("\n XGBoost lasso offset-  ORF with lasso offset") ;  nested.compare0_0_5_3(xgb.perf.rep[,6] ,  orf.perf.rep[,3], pow, bootstrap, digits)   
+      cat ("\n XGBoost lasso offset-  ORF with lasso offset") ;  nested.compare0_0_6_1(xgb.perf.rep[,6] ,  orf.perf.rep[,3], pow, bootstrap, digits)   
     }
   }
   
   if ((doxgb == 1) & (doann == 1)) {
-    cat ("\n XGBoost (tuned) - ANN                       ") ;  nested.compare0_0_5_3(xgb.perf.rep[,4] ,  ann.perf.rep[,1], pow, bootstrap, digits)   
+    cat ("\n XGBoost (tuned) - ANN                       ") ;  nested.compare0_0_6_1(xgb.perf.rep[,4] ,  ann.perf.rep[,1], pow, bootstrap, digits)   
     if (ensemble[6]) { 
-      cat ("\n XGBoost lasso feature - ANN, l lasso feature ") ;  nested.compare0_0_5_3(xgb.perf.rep[,5] ,  ann.perf.rep[,6], pow, bootstrap, digits)   
+      cat ("\n XGBoost lasso feature - ANN, l lasso feature ") ;  nested.compare0_0_6_1(xgb.perf.rep[,5] ,  ann.perf.rep[,6], pow, bootstrap, digits)   
     } else if (ensemble[2]) { 
-      cat ("\n XGBoost lasso feature - ANN lasso feature   ") ;  nested.compare0_0_5_3(xgb.perf.rep[,5] ,  ann.perf.rep[,2], pow, bootstrap, digits)   
+      cat ("\n XGBoost lasso feature - ANN lasso feature   ") ;  nested.compare0_0_6_1(xgb.perf.rep[,5] ,  ann.perf.rep[,2], pow, bootstrap, digits)   
     } 
     if (family == "gaussian") {
       if (ensemble[8]) { 
-        cat ("\n XGBoost lasso offset-ANN l lasso offset(upated) ") ;  nested.compare0_0_5_3(xgb.perf.rep[,6] ,  ann.perf.rep[,8], pow, bootstrap, digits)   
+        cat ("\n XGBoost lasso offset-ANN l lasso offset(upated) ") ;  nested.compare0_0_6_1(xgb.perf.rep[,6] ,  ann.perf.rep[,8], pow, bootstrap, digits)   
       } else if (ensemble[4]) { 
-        cat ("\n XGBoost lasso offset - ANN, lasso offset   ") ;  nested.compare0_0_5_3(xgb.perf.rep[,6] ,  ann.perf.rep[,4], pow, bootstrap, digits)   
+        cat ("\n XGBoost lasso offset - ANN, lasso offset   ") ;  nested.compare0_0_6_1(xgb.perf.rep[,6] ,  ann.perf.rep[,4], pow, bootstrap, digits)   
       } else if (ensemble[7]) { 
-        cat ("\n XGBoost lasso offset - ANN l lasso offset  ") ;  nested.compare0_0_5_3(xgb.perf.rep[,6] ,  ann.perf.rep[,7], pow, bootstrap, digits)   
+        cat ("\n XGBoost lasso offset - ANN l lasso offset  ") ;  nested.compare0_0_6_1(xgb.perf.rep[,6] ,  ann.perf.rep[,7], pow, bootstrap, digits)   
       } else if (ensemble[3]) { 
-        cat ("\n XGBoost offset - ANN lasso offset          ") ;  nested.compare0_0_5_3(xgb.perf.rep[,6] ,  ann.perf.rep[,3], pow, bootstrap, digits)   
+        cat ("\n XGBoost offset - ANN lasso offset          ") ;  nested.compare0_0_6_1(xgb.perf.rep[,6] ,  ann.perf.rep[,3], pow, bootstrap, digits)   
       }  
     }
   }
@@ -427,50 +443,50 @@ nested.compare_0_5_3 = function( object, type="devrat", digits=4, pow=1 ) {
   if (doxgb) { cat("\n") }
   
   if ((dorf == 1) & (doorf == 1)) {
-    cat ("\n RF - ORF                                    ") ;  nested.compare0_0_5_3(rf.perf.rep[,1] ,  orf.perf.rep[,1], pow, bootstrap, digits) 
+    cat ("\n RF - ORF                                    ") ;  nested.compare0_0_6_1(rf.perf.rep[,1] ,  orf.perf.rep[,1], pow, bootstrap, digits) 
     if (sum(ensemble[c(2,6)]) > 0) {
-      cat ("\n RF lasso feature - ORF l lasso feature      " ) ;  nested.compare0_0_5_3(rf.perf.rep[,2] , orf.perf.rep[,2], pow, bootstrap, digits) 
+      cat ("\n RF lasso feature - ORF l lasso feature      " ) ;  nested.compare0_0_6_1(rf.perf.rep[,2] , orf.perf.rep[,2], pow, bootstrap, digits) 
     }  
     if (sum(ensemble[c(3,4,7,8)]) > 0) {
-      cat ("\n RF lasso feature - ORF lasso feature        " ) ;  nested.compare0_0_5_3(rf.perf.rep[,3] , orf.perf.rep[,3], pow, bootstrap, digits)  
+      cat ("\n RF lasso feature - ORF lasso feature        " ) ;  nested.compare0_0_6_1(rf.perf.rep[,3] , orf.perf.rep[,3], pow, bootstrap, digits)  
     }
     cat("\n")
   }
   
   if ((dorf == 1) & (doann == 1)) {
-    cat ("\n RF - ANN                                    ") ;  nested.compare0_0_5_3(rf.perf.rep[,1] ,  ann.perf.rep[,1], pow, bootstrap, digits) 
+    cat ("\n RF - ANN                                    ") ;  nested.compare0_0_6_1(rf.perf.rep[,1] ,  ann.perf.rep[,1], pow, bootstrap, digits) 
     if (ensemble[6]) {
-      cat ("\n RF lasso feature - ANN  l lasso feature     " ) ;  nested.compare0_0_5_3(rf.perf.rep[,2] ,  ann.perf.rep[,6], pow, bootstrap, digits) 
+      cat ("\n RF lasso feature - ANN  l lasso feature     " ) ;  nested.compare0_0_6_1(rf.perf.rep[,2] ,  ann.perf.rep[,6], pow, bootstrap, digits) 
     } else if (ensemble[2]) {
-      cat ("\n RF lasso feature - ANN lasso feature        " ) ;  nested.compare0_0_5_3(rf.perf.rep[,2] ,  ann.perf.rep[,2], pow, bootstrap, digits)  
+      cat ("\n RF lasso feature - ANN lasso feature        " ) ;  nested.compare0_0_6_1(rf.perf.rep[,2] ,  ann.perf.rep[,2], pow, bootstrap, digits)  
     }
     if (ensemble[8]) {
-      cat ("\n RF lasso offset - ANN l lasso offset (upated) " ) ;  nested.compare0_0_5_3(rf.perf.rep[,3] ,  ann.perf.rep[,8], pow, bootstrap, digits)   
+      cat ("\n RF lasso offset - ANN l lasso offset (upated) " ) ;  nested.compare0_0_6_1(rf.perf.rep[,3] ,  ann.perf.rep[,8], pow, bootstrap, digits)   
     } else if (ensemble[4]) {
-      cat ("\n RF lasso offset - ANN lasso offset           " ) ;  nested.compare0_0_5_3(rf.perf.rep[,3] ,  ann.perf.rep[,4], pow, bootstrap, digits)  
+      cat ("\n RF lasso offset - ANN lasso offset           " ) ;  nested.compare0_0_6_1(rf.perf.rep[,3] ,  ann.perf.rep[,4], pow, bootstrap, digits)  
     } else if (ensemble[7]) {
-      cat ("\n RF lasso offset - ANN, l lasso offset (upated) " ) ;  nested.compare0_0_5_3(rf.perf.rep[,3] ,  ann.perf.rep[,7], pow, bootstrap, digits) 
+      cat ("\n RF lasso offset - ANN, l lasso offset (upated) " ) ;  nested.compare0_0_6_1(rf.perf.rep[,3] ,  ann.perf.rep[,7], pow, bootstrap, digits) 
     } else if (ensemble[3]) {
-      cat ("\n RF lasso offset - ANN, lasso offset          " ) ;  nested.compare0_0_5_3(rf.perf.rep[,3] ,  ann.perf.rep[,3], pow, bootstrap, digits)  
+      cat ("\n RF lasso offset - ANN, lasso offset          " ) ;  nested.compare0_0_6_1(rf.perf.rep[,3] ,  ann.perf.rep[,3], pow, bootstrap, digits)  
     }
     cat("\n")
   }
   
   if ((doorf == 1) & (doann == 1)) {
-    cat ("\n ORF - ANN                                   ") ;  nested.compare0_0_5_3(orf.perf.rep[,1] ,  ann.perf.rep[,1], pow, bootstrap, digits) 
+    cat ("\n ORF - ANN                                   ") ;  nested.compare0_0_6_1(orf.perf.rep[,1] ,  ann.perf.rep[,1], pow, bootstrap, digits) 
     if (ensemble[6]) {
-      cat ("\n ORF lasso feature - ANN  l lasso feature    " ) ;  nested.compare0_0_5_3(orf.perf.rep[,2] ,  ann.perf.rep[,6], pow, bootstrap, digits) 
+      cat ("\n ORF lasso feature - ANN  l lasso feature    " ) ;  nested.compare0_0_6_1(orf.perf.rep[,2] ,  ann.perf.rep[,6], pow, bootstrap, digits) 
     } else if (ensemble[2]) {
-      cat ("\n ORF lasso feature - ANN lasso feature       " ) ;  nested.compare0_0_5_3(orf.perf.rep[,2] ,  ann.perf.rep[,2], pow, bootstrap, digits)  
+      cat ("\n ORF lasso feature - ANN lasso feature       " ) ;  nested.compare0_0_6_1(orf.perf.rep[,2] ,  ann.perf.rep[,2], pow, bootstrap, digits)  
     }
     if (ensemble[8]) {
-      cat ("\n ORF lasso offset - ANN l lasso offset (upated)" ) ;  nested.compare0_0_5_3(orf.perf.rep[,3] ,  ann.perf.rep[,8], pow, bootstrap, digits)   
+      cat ("\n ORF lasso offset - ANN l lasso offset (upated)" ) ;  nested.compare0_0_6_1(orf.perf.rep[,3] ,  ann.perf.rep[,8], pow, bootstrap, digits)   
     } else if (ensemble[4]) {
-      cat ("\n ORF lasso offset - ANN lasso offset          " ) ;  nested.compare0_0_5_3(orf.perf.rep[,3] ,  ann.perf.rep[,4], pow, bootstrap, digits)  
+      cat ("\n ORF lasso offset - ANN lasso offset          " ) ;  nested.compare0_0_6_1(orf.perf.rep[,3] ,  ann.perf.rep[,4], pow, bootstrap, digits)  
     } else if (ensemble[7]) {
-      cat ("\n ORF lasso offset - ANN, l lasso offset (upated)" ) ;  nested.compare0_0_5_3(orf.perf.rep[,3] ,  ann.perf.rep[,7], pow, bootstrap, digits) 
+      cat ("\n ORF lasso offset - ANN, l lasso offset (upated)" ) ;  nested.compare0_0_6_1(orf.perf.rep[,3] ,  ann.perf.rep[,7], pow, bootstrap, digits) 
     } else if (ensemble[3]) {
-      cat ("\n ORF lasso offset - ANN, lasso offset         " ) ;  nested.compare0_0_5_3(orf.perf.rep[,3] ,  ann.perf.rep[,3], pow, bootstrap, digits)  
+      cat ("\n ORF lasso offset - ANN, lasso offset         " ) ;  nested.compare0_0_6_1(orf.perf.rep[,3] ,  ann.perf.rep[,3], pow, bootstrap, digits)  
     }
     cat("\n")
   }
@@ -480,33 +496,3 @@ nested.compare_0_5_3 = function( object, type="devrat", digits=4, pow=1 ) {
 
 ###############################################################################################################
 ###############################################################################################################
-
-#' A redirect to nested.compare
-#'
-#' @description 
-#' See nested.compare(), as glmnetr.compcv() is depricated  
-#'
-#' @param object A nested.glmnetr output object.
-#' @param digits digits for printing of z-scores, p-values, etc. with default of 4 
-#' @param pow the power to which the average of correlations is to be raised.   
-#' @param type determines what type of nested cross validation performance measures are 
-#' compared.  Possible values are "devrat" to compare the deviance ratios, i.e. the 
-#' fractional reduction in deviance relative to the null model deviance, 
-#' "agree" to compare agreement, "lincal" to compare the linear calibration 
-#' slope coefficients, "intcal" to compare the linear calibration intercept 
-#' coefficients, from the nested cross validation. 
-#'  
-#' @return A printout to the R console. 
-#' 
-#' @seealso
-#'   \code{\link{nested.compare}}
-#' 
-#' @export
-#' 
-
-glmnetr.compcv = function(object, digits=4, type="devrat", pow=1) {
-  nested.compare(object, type, digits, pow) 
-}
-  
-###############################################################################################################
-###############################################################################################################
